==> removedrive-1.0.0.tgz: package/README.md <==
removedrive
-----------

[![npm version](https://badge.fury.io/js/removedrive.svg)](http://badge.fury.io/js/removedrive)
[![dependencies](https://david-dm.org/jviotti/removedrive.png)](https://david-dm.org/jviotti/removedrive.png)
[![Build status](https://ci.appveyor.com/api/projects/status/37yd29p9x93qobtx/branch/master?svg=true)](https://ci.appveyor.com/project/resin-io/removedrive/branch/master)

Safely remove a drive on Windows.

Installation
------------

Install `removedrive` by running:

```sh
$ npm install --save removedrive
```

Documentation
-------------

<a name="module_removedrive.eject"></a>
### removedrive.eject(driveLetter, callback)
Running this function requires administration permissions.

**Kind**: static method of <code>[removedrive](#module_removedrive)</code>  
**Summary**: Eject a drive by it&#x27;s letter  
**Access:** public  

| Param | Type | Description |
| --- | --- | --- |
| driveLetter | <code>String</code> | drive letter |
| callback | <code>function</code> | callback (error) |

**Example**  
```js
removedrive.eject('D', function(error) {
  if (error) throw error;
});
```

Support
-------

If you're having any problem, please [raise an issue](https://github.com/jviotti/removedrive/issues/new) on GitHub and the jviotti team will be happy to help.

Tests
-----

Run the test suite by doing:

```sh
$ gulp test
```

Contribute
----------

- Issue Tracker: [github.com/jviotti/removedrive/issues](https://github.com/jviotti/removedrive/issues)
- Source Code: [github.com/jviotti/removedrive](https://github.com/jviotti/removedrive)

Before submitting a PR, please make sure that you include tests, and that [jshint](http://jshint.com) runs without any warning:

```sh
$ gulp lint
```

License
-------

The project is licensed under the MIT license.

==> removedrive-1.1.2.tgz: package/README.md <==
removedrive
-----------

[![npm version](https://badge.fury.io/js/removedrive.svg)](http://badge.fury.io/js/removedrive)
[![dependencies](https://david-dm.org/jviotti/removedrive.png)](https://david-dm.org/jviotti/removedrive.png)
[![Build status](https://ci.appveyor.com/api/projects/status/37yd29p9x93qobtx/branch/master?svg=true)](https://ci.appveyor.com/project/resin-io/removedrive/branch/master)

Safely remove a drive on Windows.

Installation
------------

Install `removedrive` by running:

```sh
$ npm install --save removedrive
```

Documentation
-------------

<a name="module_removedrive.eject"></a>
### removedrive.eject(driveLetter, callback)
Running this function requires administration permissions.

**Kind**: static method of <code>[removedrive](#module_removedrive)</code>  
**Summary**: Eject a drive by it's letter or identifier  
**Access:** public  

| Param | Type | Description |
| --- | --- | --- |
| driveLetter | <code>String</code> | drive letter |
| callback | <code>function</code> | callback (error) |

**Example**  
```js
removedrive.eject('D', function(error) {
  if (error) throw error;
});
```
**Example**  
```js
removedrive.eject('\\\\.\\PHYSICALDRIVE2', function(error) {
  if (error) throw error;
});
```

Support
-------

If you're having any problem, please [raise an issue](https://github.com/jviotti/removedrive/issues/new) on GitHub and the jviotti team will be happy to help.

Tests
-----

Run the test suite by doing:

```sh
$ gulp test
```

Contribute
----------

- Issue Tracker: [github.com/jviotti/removedrive/issues](https://github.com/jviotti/removedrive/issues)
- Source Code: [github.com/jviotti/removedrive](https://github.com/jviotti/removedrive)

Before submitting a PR, please make sure that you include tests, and that [jshint](http://jshint.com) runs without any warning:

```sh
$ gulp lint
```

License
-------

The project is licensed under the MIT license.
